Thanks for your interest in contributing to the Salt Extension Modules for
HashiCorp Vault! We welcome any contribution, large or small - from
adding a new feature to fixing a single letter typo.

This is a companion to the Salt Project and the [Salt Contributing
Guide][salt-contributing] should be considered the default for this project.
Where this project disagrees with the Salt Project, the guidelines here take
precedence. Where this project is silent, the Salt guidelines should be used.

See the **Contributing** section in the [README][README.md] for a quickstart.


[README.md]: README.md
[salt-contributing]: https://docs.saltproject.io/en/master/topics/development/contributing.html
